@@ -25,7 +25,8 @@ class ChatbotGPT:
             stop=None,
             temperature=0.5,
         )
-        return response.choices[0].text.strip()
+        text = response.choices[0].text.strip()
+        return text.replace('\\n', '\n')
 
     def ask(self):
         #  ask the user to give input
